searchData={"items":[{"type":"module","title":"Logster","doc":"An easy-to-parse, single-line logger for Elixir Phoenix and Plug.Conn, inspired by [lograge](https://github.com/roidrage/lograge). Supports logfmt, JSON and custom output formatting.\n\nBy default, Phoenix log output for a request looks similar to the following:\n\n```\n[info] GET /articles/some-article\n[debug] Processing with HelloPhoenix.ArticleController.show/2\n  Parameters: %{\"id\" => \"some-article\"}\n  Pipelines: [:browser]\n[info] Sent 200 in 21ms\n```\n\nThis can be handy for development, but cumbersome for production. The log output is spread across multiple lines, making it difficult to parse and search.\n\nLogster aims to solve this problem by logging the request in a single line:\n\n```\n[info] state=sent method=GET path=/articles/some-article format=html controller=HelloPhoenix.ArticleController action=show params={\"id\":\"some-article\"} status=200 duration=0.402\n```\n\nThis is especially handy when integrating with log management services such as [Logentries](https://logentries.com/) or [Papertrail](https://papertrailapp.com/).\n\nAlternatively, Logster can also output JSON formatted logs (see configuration section below):\n\n```\n[info] {\"state\":\"sent\",\"method\":\"GET\",\"path\":\"/articles/some-article\",\"format\":\"html\",\"controller\":\"HelloPhoenix.ArticleController\",\"action\":\"show\",\"params\":{\"id\":\"some-article\"},\"status\":200,\"duration\":0.402}\n```","ref":"Logster.html"},{"type":"module","title":"Installation - Logster","doc":"Add `:logster` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:logster, \"~> 2.0.0-rc.1\"}]\nend\n```","ref":"Logster.html#module-installation"},{"type":"module","title":"Upgrading - Logster","doc":"See [Upgrade Guide](UPGRADE_GUIDE.md) for more information.","ref":"Logster.html#module-upgrading"},{"type":"module","title":"Usage - Logster","doc":"#","ref":"Logster.html#module-usage"},{"type":"module","title":"Using with Phoenix - Logster","doc":"Attach the Logster Phoenix logger in the `start` function in your project's `application.ex` file:\n\n```elixir\n# lib/my_app/application.ex\ndef start(_type, _args) do\n  children = [\n    # ...\n  ]\n\n  #\n  # Add the line below:\n  #\n  :ok = Logster.attach_phoenix_logger()\n\n  opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n  Supervisor.start_link(children, opts)\nend\n```\n\nNext, disable the default Phoenix logger by adding the following line to your `config.exs` file:\n\n```elixir\nconfig :phoenix, :logger, false\n```\n\n#","ref":"Logster.html#module-using-with-phoenix"},{"type":"module","title":"Using with Plug - Logster","doc":"Add `Logster.Plug` to your plug pipeline, or in the relevant module:\n\n```elixir\nplug Logster.Plug\n```\n\n#","ref":"Logster.html#module-using-with-plug"},{"type":"module","title":"Using standalone logger - Logster","doc":"Logster provides `debug`, `info`, `warning`, `error` etc convenience functions that mimic those provided by the elixir logger, which outputs messages in your chosen log format.\n\nFor example:\n\n```elixir\nLogger.info(service: :payments, event: :received, amount: 1000, customer: 123)\n```\n\nwill output the following to the logs:\n\n```\n[info] service=payments event=received amount=1000 customer=123\n```\n\nYou can also provide a function to be called lazily, which will only be called if the log level is enabled:\n\n```elixir\nLogger.debug(fn ->\n  # some potentially expensive operation\n  # won't be called if the log level is not enabled\n  customer = get_customer_id()\n\n  [service: :payments, event: :received, amount: 1000, customer: customer]\nend)\n```","ref":"Logster.html#module-using-standalone-logger"},{"type":"module","title":"Configuration - Logster","doc":"The following configuration options can be set through your `config.exs` file\n\n#","ref":"Logster.html#module-configuration"},{"type":"module","title":"Formatter - Logster","doc":"##","ref":"Logster.html#module-formatter"},{"type":"module","title":"JSON formatter - Logster","doc":"```elixir\nconfig :logster, formatter: :json\n```\n\n_Caution:_ There is no guarantee that what reaches your console will be valid JSON. The Elixir `Logger` module has its own formatting which may be appended to your message. See the [Logger documentation](http://elixir-lang.org/docs/stable/logger/Logger.html) for more information.\n\n##","ref":"Logster.html#module-json-formatter"},{"type":"module","title":"Custom formatter - Logster","doc":"Provide a function that takes one argument, the parameters as input, and returns formatted output\n\n```elixir\nconfig :logster, formatter: &MyCustomFormatter.format/1\n```\n\n#","ref":"Logster.html#module-custom-formatter"},{"type":"module","title":"Filtering parameters - Logster","doc":"By default, Logster filters parameters named `password`.\n\nTo change the filtered parameters:\n\n```elixir\nconfig :logster, filter_parameters: [\"password\", \"secret\", \"token\"]\n```\n\n#","ref":"Logster.html#module-filtering-parameters"},{"type":"module","title":"Logging HTTP request headers - Logster","doc":"By default, Logster won't log any request headers. To log specific headers, you can use the `:headers` option:\n\n```elixir\nconfig :logster, headers: [\"my-header-one\", \"my-header-two\"]\n```\n\n#","ref":"Logster.html#module-logging-http-request-headers"},{"type":"module","title":"Changing the log level for a specific controller/action - Logster","doc":"##","ref":"Logster.html#module-changing-the-log-level-for-a-specific-controller-action"},{"type":"module","title":"Through Logster.ChangeLogLevel plug - Logster","doc":"To change the Logster log level for a specific controller and/or action, you use the `Logster.ChangeLogLevel` plug.\n\nFor example, to change the logging of all requests in a controller to `debug`, add the following to that controller:\n\n```elixir\nplug Logster.ChangeLogLevel, to: :debug\n```\n\nAnd to change it only for `index` and `show` actions:\n\n```elixir\nplug Logster.ChangeLogLevel, [to: :debug] when action in [:index, :show]\n```\n\nThis is specially useful for cases such as when you want to lower the log level for a healthcheck endpoint that gets hit every few seconds.\n\n##","ref":"Logster.html#module-through-logster-changeloglevel-plug"},{"type":"module","title":"Through endpoint configuration - Logster","doc":"You can set the `Plug.Telemetry` `:log` option to a tuple, `{Mod, Fun, Args}`. `The Plug.Conn.t()` for the request will be prepended to the provided list of arguments.\n\nWhen invoked, your function must return a `Logger.level()` or `false` to disable logging for the request.\n\n```elixir\n# lib/my_app_web/endpoint.ex\nplug Plug.Telemetry,\n  event_prefix: [:phoenix, :endpoint],\n  log: {__MODULE__, :log_level, []}\n\n# Disables logging for routes like /status/*\ndef log_level(%{status: status}) when status >= 500, do: :error\ndef log_level(%{status: status}) when status >= 400, do: :warning\ndef log_level(%{path_info: [\"status\" | _]}), do: false\ndef log_level(_), do: :info\n```\n\n#","ref":"Logster.html#module-through-endpoint-configuration"},{"type":"module","title":"Enabling extra fields - Logster","doc":"One or more of the following fields can be optionally enabled through the `extra_fields` configuration option:\n\n- host\n- query\n\nExample:\n\n```elixir\nconfig :logster, extra_fields: [:host, :query]\n```\n\n#","ref":"Logster.html#module-enabling-extra-fields"},{"type":"module","title":"Renaming default fields - Logster","doc":"You can rename the default keys passing a map like `%{key: :new_key}`:\n\n```elixir\nconfig :logster, renames: [duration: :response_time, params: :parameters]\n```\n\nExample output:\n\n```\n[info] method=GET path=/articles/some-article format=html controller=HelloPhoenix.ArticleController action=show parameters={\"id\":\"some-article\"} status=200 response_time=0.402 state=set\n```\n\n#","ref":"Logster.html#module-renaming-default-fields"},{"type":"module","title":"Excluding fields - Logster","doc":"You can exclude fields with `:excludes`:\n\n```elixir\nconfig :logster, excludes: [:params, :status, :state]\n```\n\nExample output:\n\n```\n[info] method=GET path=/articles/some-article format=html controller=HelloPhoenix.ArticleController action=show duration=0.402\n```\n\n#","ref":"Logster.html#module-excluding-fields"},{"type":"module","title":"Metadata - Logster","doc":"Custom metadata can be added to logs using `Logger.metadata` and configuring your logger backend:\n\n```elixir\n# add metadata for all future logs from this process\nLogger.metadata(%{user_id: \"123\", foo: \"bar\"})\n\n# example for configuring console backend to include metadata in logs.\n# see https://hexdocs.pm/logger/Logger.html#module-console-backend documentation for more\n# config.exs\nconfig :logger, :console, metadata: [:user_id, :foo]\n```\n\nThe easiest way to do this app wide is to introduce a new plug which you can include in your Phoenix router pipeline.\n\nFor example:\n\n```elixir\ndefmodule HelloPhoenix.SetLoggerMetadata do\n  def init(opts), do: opts\n\n  def call(conn, _opts) do\n    Logger.metadata user_id: get_user_id(conn),\n                    remote_ip: format_ip(conn)\n    conn\n  end\n\n  defp format_ip(%{remote_ip: remote_ip}) when remote_ip != nil, do: :inet_parse.ntoa(remote_ip)\n  defp format_ip(_), do: nil\n\n  defp get_user_id(%{assigns: %{current_user: %{id: id}}}), do: id\n  defp get_user_id(_), do: nil\nend\n```\n\nAnd then add this plug to the relevant pipelines in the router:\n\n```elixir\npipeline :browser do\n  plug :fetch_session\n  plug :fetch_flash\n  plug :put_secure_browser_headers\n  # ...\n  plug HelloPhoenix.SetLoggerMetadata\n  # ...\nend\n```","ref":"Logster.html#module-metadata"},{"type":"function","title":"Logster.alert/2","doc":"Logs a alert message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#alert/2"},{"type":"function","title":"Logster.attach_phoenix_logger/0","doc":"Attaches a telemetry handler to the `:phoenix` event stream for logging.\n\nReturns `:ok`.","ref":"Logster.html#attach_phoenix_logger/0"},{"type":"function","title":"Logster.critical/2","doc":"Logs a critical message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#critical/2"},{"type":"function","title":"Logster.debug/2","doc":"Logs a debug message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#debug/2"},{"type":"function","title":"Logster.detach_phoenix_logger/0","doc":"Detaches logster's telemetry handler from the `:phoenix` event stream.\n\nReturns `:ok`.","ref":"Logster.html#detach_phoenix_logger/0"},{"type":"function","title":"Logster.emergency/2","doc":"Logs a emergency message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#emergency/2"},{"type":"function","title":"Logster.error/2","doc":"Logs a error message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#error/2"},{"type":"function","title":"Logster.info/2","doc":"Logs a info message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#info/2"},{"type":"function","title":"Logster.levels/0","doc":"","ref":"Logster.html#levels/0"},{"type":"function","title":"Logster.log/3","doc":"Logs a message with the given `level`.\n\nIf given an enumerable, the enumerable will be formatted using the configured formatter.\n\nReturns `:ok`.\n\nUsing `debug/2`, `info/2`, `notice/2`, `warning/2`, `error/2`, `critical/2`, `alert/2`,\nand `emergency/2` are preferred over this function as they can automatically eliminate\nthe call to `Logger` altogether at compile time if desired\n(see the documentation for the `Logger` module).","ref":"Logster.html#log/3"},{"type":"function","title":"Example - Logster.log/3","doc":"```\nLogster.log(:info, service: \"payment-processor\", event: \"start-processing\", customer: \"1234\")\n```\n\nwill produce the following log entry when using the `logfmt` formatter:\n\n```\n16:54:29.919 [info] service=payment-processor event=start-processing customer=1234\n```","ref":"Logster.html#log/3-example"},{"type":"function","title":"Logster.log_conn/4","doc":"Logs details about the given `conn` at the given `level`.\n\nSee the module documentation for more information on configuration options.\n\nReturns `:ok`.","ref":"Logster.html#log_conn/4"},{"type":"function","title":"Logster.notice/2","doc":"Logs a notice message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#notice/2"},{"type":"function","title":"Logster.warning/2","doc":"Logs a warning message. See `Logster.log/3` for more information.\n\nReturns `:ok`.","ref":"Logster.html#warning/2"},{"type":"module","title":"Logster.ChangeLogLevel","doc":"A plug for changing the log level used by Logster. Useful for increasing/decreasing the log level on a per controller or action basis\n\nTo change the log level for a specific controller, add the following in the controller\n\n  plug Logster.Plugs.ChangeLogLevel, to: :debug\n\nTo specify it only for a specific action, add the following:\n\n  plug Logster.Plugs.ChangeLogLevel, to: :debug when action in [:index, :show]","ref":"Logster.ChangeLogLevel.html"},{"type":"function","title":"Logster.ChangeLogLevel.call/2","doc":"","ref":"Logster.ChangeLogLevel.html#call/2"},{"type":"function","title":"Logster.ChangeLogLevel.init/1","doc":"","ref":"Logster.ChangeLogLevel.html#init/1"},{"type":"module","title":"Logster.Formatters.JSON","doc":"","ref":"Logster.Formatters.JSON.html"},{"type":"function","title":"Logster.Formatters.JSON.format/1","doc":"","ref":"Logster.Formatters.JSON.html#format/1"},{"type":"module","title":"Logster.Formatters.String","doc":"","ref":"Logster.Formatters.String.html"},{"type":"function","title":"Logster.Formatters.String.format/1","doc":"","ref":"Logster.Formatters.String.html#format/1"},{"type":"module","title":"Logster.Plug","doc":"A plug for logging request information in the format:\n\n    method=GET path=/articles/some-article format=html controller=HelloPhoenix.ArticleController action=show params={\"id\":\"some-article\"} status=200 duration=0.402 state=set\n\nTo use it, just plug it into the desired module.\n\n    plug Logster.Plug, log: :debug","ref":"Logster.Plug.html"},{"type":"module","title":"Options - Logster.Plug","doc":"* `:log` - The log level at which this plug should log its request info.\n    Default is `:info`.","ref":"Logster.Plug.html#module-options"},{"type":"function","title":"Logster.Plug.call/2","doc":"","ref":"Logster.Plug.html#call/2"},{"type":"function","title":"Logster.Plug.init/1","doc":"","ref":"Logster.Plug.html#init/1"},{"type":"extras","title":"Upgrade Guide","doc":"# Upgrade Guide","ref":"upgrade_guide.html"},{"type":"extras","title":"v1.x to v2.0.0 - Upgrade Guide","doc":"#","ref":"upgrade_guide.html#v1-x-to-v2-0-0"},{"type":"extras","title":"Phoenix users: - Upgrade Guide","doc":"1. Attach the new logger through telemetry events in your project's `application.ex` file:\n\n   ```elixir\n   # lib/pixie/application.ex\n   def start(_type, _args) do\n     children = [\n       # ...\n     ]\n\n     #\n     # Add the line below:\n     #\n     :ok = Logster.attach_phoenix_logger()\n\n     opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n     Supervisor.start_link(children, opts)\n   end\n   ```\n\n2. Locate the line installing `Logster.Plugs.Logger` in your `endpoint.ex` file.\n\n   ```elixir\n   plug Logster.Plugs.Logger,\n     # Configuration options such as those below might not be present\n     formatter: Logster.Plugs.JSONFormatter,\n     allowed_headers: [\"content-type\"],\n     excludes: [:params]\n   ```\n\n3. If configuration options were passed to `Logster.Plugs.Logger`, move them to `config.exs`:\n\n   ```elixir\n   config :logster,\n     formatter: :json,\n     headers: [\"content-type\"],\n     excludes: [:params]\n   ```\n\n   > NOTE: `allowed_headers` option has been renamed to `headers`\n\n4. Remove the line installing `Logster.Plugs.Logger` from your `endpoint.ex` file.\n\n5. Locate any calls to `Logster.Plugs.ChangeLogLevel` and rename it to `Logster.ChangeLogLevel`\n\n6. Add the following to `config.exs` to disable the default Phoenix logger:\n\n   ```elixir\n   config :phoenix, :logger, false\n   ```\n\n#","ref":"upgrade_guide.html#phoenix-users"},{"type":"extras","title":"Plug users: - Upgrade Guide","doc":"1. Move any configuration options passed to `Logster.Plugs.Logger` to `config.exs` (See above section for more information).\n\n1. Locate any calls to `Logster.Plugs.Logger` and rename it to `Logster.Plug`\n\n1. Locate any calls to `Logster.Plugs.ChangeLogLevel` and rename it to `Logster.ChangeLogLevel`","ref":"upgrade_guide.html#plug-users"}],"content_type":"text/markdown"}